@@ -8,7 +8,6 @@ use crate::{
 pub struct Mode {
     pub typ: library::TypeId,
     pub transfer: library::Transfer,
-    pub is_uninitialized: bool,
     pub try_from_glib: TryFromGlib,
 }
 
@@ -17,7 +16,6 @@ impl From<&parameter_ffi_call_out::Parameter> for Mode {
         Mode {
             typ: orig.typ,
             transfer: orig.transfer,
-            is_uninitialized: orig.is_uninitialized,
             try_from_glib: orig.try_from_glib.clone(),
         }
     }
@@ -28,7 +26,6 @@ impl From<&analysis::Parameter> for Mode {
         Mode {
             typ: orig.lib_par.typ,
             transfer: orig.lib_par.transfer,
-            is_uninitialized: false,
             try_from_glib: orig.try_from_glib.clone(),
         }
     }
