@@ -89,12 +89,11 @@ fn generate_enum(
 
     let mut members: Vec<Member<'_>> = Vec::new();
     let mut vals: HashSet<String> = HashSet::new();
-    let sys_crate_name = env.main_sys_crate_name();
+    let sys_crate_name = env.sys_crate_import(analysis.type_id);
 
     for member in &enum_.members {
         let member_config = config.members.matched(&member.name);
-        let is_alias = member_config.iter().any(|m| m.alias);
-        if is_alias || member.status.ignored() || vals.contains(&member.value) {
+        if member.status.ignored() || vals.contains(&member.value) {
             continue;
         }
         vals.insert(member.value.clone());
