@@ -25,7 +25,7 @@ pub fn generate(
 
         let mut path = root_path.join(&mod_name);
         path.set_extension("rs");
-        info!("Generating file {:?}", path);
+        info!("Generating file {path:?}");
 
         save_to_file(path, env.config.make_backup, |w| {
             super::object::generate(w, env, class_analysis)
