@@ -195,7 +195,7 @@ fn is_name_made_up(name: &str) -> bool {
 }
 
 fn generate_manual_h(env: &Env, path: &Path, w: &mut dyn Write) -> io::Result<()> {
-    info!("Generating file {:?}", path);
+    info!("Generating file {path:?}");
     writeln!(
         w,
         "// Feel free to edit this file, it won't be regenerated by gir generator unless removed."
@@ -217,7 +217,7 @@ fn generate_layout_c(
     w: &mut dyn Write,
     ctypes: &[CType],
 ) -> io::Result<()> {
-    info!("Generating file {:?}", path);
+    info!("Generating file {path:?}");
     general::start_comments(w, &env.config)?;
     writeln!(w)?;
     writeln!(w, "#include \"manual.h\"")?;
@@ -245,7 +245,7 @@ fn generate_constant_c(
     w: &mut dyn Write,
     cconsts: &[CConstant],
 ) -> io::Result<()> {
-    info!("Generating file {:?}", path);
+    info!("Generating file {path:?}");
     general::start_comments(w, &env.config)?;
     writeln!(w)?;
     writeln!(w, "#include \"manual.h\"")?;
@@ -306,7 +306,7 @@ fn generate_abi_rs(
         package_names = format!("\"{package_names}\"");
     }
 
-    info!("Generating file {:?}", path);
+    info!("Generating file {path:?}");
     general::start_comments(w, &env.config)?;
     writeln!(w)?;
     writeln!(w, "#![cfg(unix)]")?;
