@@ -230,6 +230,13 @@ pub enum Basic {
     Type,
     IntPtr,
     UIntPtr,
+    TimeT,
+    OffT,
+    DevT,
+    GidT,
+    PidT,
+    SockLenT,
+    UidT,
     // Same encoding as Filename but can contains any string
     // Not defined in GLib directly
     OsString,
@@ -303,6 +310,13 @@ const BASIC: &[(&str, Basic)] = &[
     // TODO: this is temporary name, change it when type added to GLib
     ("os_string", Basic::OsString),
     ("bool", Basic::Bool),
+    ("time_t", Basic::TimeT),
+    ("off_t", Basic::OffT),
+    ("dev_t", Basic::DevT),
+    ("gid_t", Basic::GidT),
+    ("pid_t", Basic::PidT),
+    ("socklen_t", Basic::SockLenT),
+    ("uid_t", Basic::UidT),
 ];
 
 #[derive(Clone, Copy, Debug, Default, Hash, PartialEq, Eq, PartialOrd, Ord)]
@@ -502,6 +516,8 @@ pub struct Property {
     pub deprecated_version: Option<Version>,
     pub doc: Option<String>,
     pub doc_deprecated: Option<String>,
+    pub getter: Option<String>,
+    pub setter: Option<String>,
 }
 
 #[derive(Clone, Debug)]
@@ -537,6 +553,11 @@ pub struct Function {
     pub deprecated_version: Option<Version>,
     pub doc: Option<String>,
     pub doc_deprecated: Option<String>,
+    pub get_property: Option<String>,
+    pub set_property: Option<String>,
+    pub finish_func: Option<String>,
+    pub async_func: Option<String>,
+    pub sync_func: Option<String>,
 }
 
 #[derive(Debug)]
@@ -1105,7 +1126,7 @@ impl Library {
                         .config
                         .objects
                         .get(&full_name)
-                        .map_or(false, |obj| obj.generate_builder)
+                        .is_some_and(|obj| obj.generate_builder)
                         && properties
                             .iter()
                             .any(|prop| prop.construct_only || prop.construct || prop.writable)
@@ -1335,7 +1356,7 @@ impl Library {
         self.namespace_mut(ns_id).versions.insert(version);
     }
 
-    pub fn types<'a>(&'a self) -> Box<dyn Iterator<Item = (TypeId, &Type)> + 'a> {
+    pub fn types<'a>(&'a self) -> Box<dyn Iterator<Item = (TypeId, &'a Type)> + 'a> {
         Box::new(self.namespaces.iter().enumerate().flat_map(|(ns_id, ns)| {
             ns.types.iter().enumerate().filter_map(move |(id, type_)| {
                 let tid = TypeId {
@@ -1351,7 +1372,7 @@ impl Library {
     pub fn namespace_types<'a>(
         &'a self,
         ns_id: u16,
-    ) -> Box<dyn Iterator<Item = (TypeId, &Type)> + 'a> {
+    ) -> Box<dyn Iterator<Item = (TypeId, &'a Type)> + 'a> {
         let ns = self.namespace(ns_id);
         Box::new(ns.index.values().map(move |&id| {
             (
